==> huaweicloudsdkcc-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/apply_policy_id.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ApplyPolicyId:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'apply_policy_id': 'str'
    }

    attribute_map = {
        'apply_policy_id': 'apply_policy_id'
    }

    def __init__(self, apply_policy_id=None):
        """ApplyPolicyId

        The model defined in huaweicloud sdk

        :param apply_policy_id: 实例ID。
        :type apply_policy_id: str
        """
        
        

        self._apply_policy_id = None
        self.discriminator = None

        self.apply_policy_id = apply_policy_id

    @property
    def apply_policy_id(self):
        """Gets the apply_policy_id of this ApplyPolicyId.

        实例ID。

        :return: The apply_policy_id of this ApplyPolicyId.
        :rtype: str
        """
        return self._apply_policy_id

    @apply_policy_id.setter
    def apply_policy_id(self, apply_policy_id):
        """Sets the apply_policy_id of this ApplyPolicyId.

        实例ID。

        :param apply_policy_id: The apply_policy_id of this ApplyPolicyId.
        :type apply_policy_id: str
        """
        self._apply_policy_id = apply_policy_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplyPolicyId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcc-3.1.143-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/apply_policy_id.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ApplyPolicyId:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'apply_policy_id': 'str'
    }

    attribute_map = {
        'apply_policy_id': 'apply_policy_id'
    }

    def __init__(self, apply_policy_id=None):
        r"""ApplyPolicyId

        The model defined in huaweicloud sdk

        :param apply_policy_id: 实例ID。
        :type apply_policy_id: str
        """
        
        

        self._apply_policy_id = None
        self.discriminator = None

        self.apply_policy_id = apply_policy_id

    @property
    def apply_policy_id(self):
        r"""Gets the apply_policy_id of this ApplyPolicyId.

        实例ID。

        :return: The apply_policy_id of this ApplyPolicyId.
        :rtype: str
        """
        return self._apply_policy_id

    @apply_policy_id.setter
    def apply_policy_id(self, apply_policy_id):
        r"""Sets the apply_policy_id of this ApplyPolicyId.

        实例ID。

        :param apply_policy_id: The apply_policy_id of this ApplyPolicyId.
        :type apply_policy_id: str
        """
        self._apply_policy_id = apply_policy_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplyPolicyId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
